/* 

Author: Gordon D. Dick, EE
        gdick@xplornet.com

Description: This code is intended to work with the AMS AS5040 absolute rotary position sensor used as a Weather Vane.
Although most likely a Weather Vane would be part of a more complex weather station, this code just shows Weather Vane
functionality.

July 20, 2015: Last day this code was worked on.

This code is developed using Arduino 1.6.3 and the Arduino R3 with the LCD/Button shield; both from Sparkfun.

LCD pinout to PORTD - note LCD rw is grounded therefore only 6 pins needed
rs->PD8, rw->gnd, E->PD9, d4->PD4, d5->PD5, d6->PD6, d7->PD7 or in terms of Arduino pins
rs->D8, rw->gnd, E->D9, d4->D4, d5->D5, d6->D6, d7->D7

*/

#include <LiquidCrystal.h>
LiquidCrystal lcd( 8, 9, 4, 5, 6, 7 );

  int iADC = 0;
  int iDir = 0;
  float fDir = 0;



void setup()
{  
  lcd.begin( 16, 2  );  delay( 2 );
  delay( 500 );
  
  lcd.setCursor(0, 0);
  lcd.print( "Weather Vane 1.1");                          //show the banner screen
  lcd.setCursor(0, 1);
  lcd.print( "by Gordon D Dick");
  delay( 3000 );                                           //                      for 3 sec

  lcd.setCursor(0, 1);                                     //erase author's name
  lcd.print( "                ");
  
  lcd.setCursor( 0, 1 );                                   //paint the operating screen
  lcd.print( "Vane:   deg" );
  
  pinMode(10, OUTPUT );                                   //
//  digitalWrite(10, HIGH );                                // turn the LCD backlight ON
  digitalWrite(10, LOW );                                // turn the LCD backlight OFF
//The backlight didn't seem to make much difference even though I determined the drive transistor was on. Later I found out that if the room
//was darker you could see the backlight. Still, not much of a backlight.
  
}


void loop()
{
  delay( 200 );
   
  iADC = analogRead( A1 );
 
  iDir = map( iADC, 0, 1023, 0, 359 );                      //convert ADC readings to compass angles
  lcd.setCursor( 5, 1 );
  lcd.print( "   " );                                      //blank last reading
  lcd.setCursor( 5, 1 );
  lcd.print( iDir, DEC );                                  //output direction in DEC to LCD
  
  fDir = iDir * 10.0;                                      //change to a float to make things easier

  lcd.setCursor( 14, 1 );
  
  if( ( fDir > 225 ) && ( fDir <= 675 ) )
    lcd.print ( "NE" );
  if( ( fDir > 675 ) && ( fDir <= 1125 ) )
    lcd.print ( " E" );
  if( ( fDir > 1125 ) && ( fDir <= 1575 ) )
    lcd.print ( "SE" );
  if( ( fDir > 1575 ) && ( fDir <= 2025 ) )
    lcd.print ( " S" );
  if( ( fDir > 2025 ) && ( fDir <= 2475 ) )
    lcd.print ( "SW" );
  if( ( fDir > 2475 ) && ( fDir <= 2925 ) )
    lcd.print ( " W" );
  if( ( fDir > 2925 ) && ( fDir <= 3375 ) )
    lcd.print ( "NW" );
  if( ( ( fDir > 3375 ) && ( fDir <= 3590 ) ) || ( ( fDir >= 0 ) && ( fDir <= 225 ) ) )
    lcd.print ( " N" );
    
}





